# API

Are you looking for API documentation for a specific class or module? If can find most of the answers in docstrings without leaving the IDE. But in case you need a web reference, here is an index of pages covering specific parts of the API.

## Public classes

+ {py:class}`walnats.Actor`
+ {py:class}`walnats.Actors`
+ {py:class}`walnats.Clock`
+ {py:class}`walnats.CloudEvent`
+ {py:class}`walnats.Event`
+ {py:class}`walnats.Events`
+ {py:class}`walnats.Limits`
+ {py:class}`walnats.Services`

## Private classes

+ {py:class}`walnats.types.BaseEvent` (undocumented)
+ {py:class}`walnats.types.ConnectedActors`
+ {py:class}`walnats.types.ConnectedEvents`
+ {py:class}`walnats.types.Context`
+ {py:class}`walnats.types.ErrorContext`
+ {py:class}`walnats.types.EventWithResponse`
+ {py:class}`walnats.types.OkContext`

## Enums

+ {py:class}`walnats.ExecuteIn`
+ {py:class}`walnats.Priority`

## Exceptions

+ {py:exc}`walnats.StreamConfigError`
+ {py:exc}`walnats.StreamExistsError`

## Modules

+ [walnats.decorators](./decorators)
+ [walnats.serializers](./serializers)
+ [walnats.middlewares](./middlewares)
